import getLog from './get-log';
import beginTransaction from './begin-transaction';
import commitTransaction from './commit-transaction';
import rollbackTransaction from './rollback-transaction';
import isTimeoutError from './is-timeout-error';

const connect = async (pool, {
  RDSDataService,
  escapeId,
  escape,
  fullJitter,
  executeStatement,
  coercer
}, config) => {
  var _eventsTableName, _snapshotsTableName, _secretsTableName;

  const log = getLog('connect');
  log.debug('configuring RDS data service client');
  let {
    databaseName,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    // eslint-disable-next-line prefer-const
    ...connectionOptions
  } = config;
  eventsTableName = (_eventsTableName = eventsTableName) !== null && _eventsTableName !== void 0 ? _eventsTableName : 'events';
  snapshotsTableName = (_snapshotsTableName = snapshotsTableName) !== null && _snapshotsTableName !== void 0 ? _snapshotsTableName : 'snapshots';
  secretsTableName = (_secretsTableName = secretsTableName) !== null && _secretsTableName !== void 0 ? _secretsTableName : 'secrets';
  const {
    dbClusterOrInstanceArn,
    awsSecretStoreArn,
    ...rdsConfig
  } = connectionOptions;

  if (dbClusterOrInstanceArn == null || awsSecretStoreArn == null) {
    throw new Error(`Options "dbClusterOrInstanceArn" and "awsSecretStoreArn" are mandatory`);
  }

  const rdsDataService = new RDSDataService(rdsConfig);
  Object.assign(pool, {
    rdsDataService,
    dbClusterOrInstanceArn,
    awsSecretStoreArn,
    databaseName,
    eventsTableName,
    secretsTableName,
    snapshotsTableName,
    fullJitter,
    coercer,
    executeStatement: executeStatement.bind(null, pool),
    beginTransaction,
    commitTransaction,
    rollbackTransaction,
    escapeId,
    escape,
    isTimeoutError
  });
  log.debug('RDS data service client configured');
};

export default connect;
//# sourceMappingURL=connect.js.map