import { EventstoreResourceNotExistError } from 'resolve-eventstore-base';
import getLog from './get-log';
import { isNotExistError } from './resource-errors';
import executeSequence from './execute-sequence';

const dropEvents = async ({
  databaseName,
  eventsTableName,
  snapshotsTableName,
  executeStatement,
  escapeId
}) => {
  const log = getLog('dropEvents');
  log.debug(`dropping events tables`);
  log.verbose(`eventsTableName: ${eventsTableName}`);
  log.verbose(`databaseName: ${databaseName}`);
  const databaseNameAsId = escapeId(databaseName);
  const eventsTableNameAsId = escapeId(eventsTableName);
  const threadsTableNameAsId = escapeId(`${eventsTableName}-threads`);
  const freezeTableNameAsId = escapeId(`${eventsTableName}-freeze`);
  const snapshotsTableNameAsId = escapeId(snapshotsTableName);
  const incrementalImportTableAsId = escapeId(`${eventsTableName}-incremental-import`);
  const aggregateIdAndVersionIndexName = escapeId(`${eventsTableName}-aggregateIdAndVersion`);
  const aggregateIndexName = escapeId(`${eventsTableName}-aggregateId`);
  const aggregateVersionIndexName = escapeId(`${eventsTableName}-aggregateVersion`);
  const typeIndexName = escapeId(`${eventsTableName}-type`);
  const timestampIndexName = escapeId(`${eventsTableName}-timestamp`);
  const statements = [`DROP TABLE ${databaseNameAsId}.${eventsTableNameAsId}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${aggregateIdAndVersionIndexName}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${aggregateIndexName}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${aggregateVersionIndexName}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${typeIndexName}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${timestampIndexName}`, `DROP TABLE ${databaseNameAsId}.${threadsTableNameAsId}`, `DROP TABLE ${databaseNameAsId}.${snapshotsTableNameAsId}`, `DROP TABLE IF EXISTS ${databaseNameAsId}.${freezeTableNameAsId}`, `DROP TABLE IF EXISTS ${databaseNameAsId}.${incrementalImportTableAsId}`];
  const errors = await executeSequence(executeStatement, statements, log, error => {
    if (isNotExistError(error.message)) {
      return new EventstoreResourceNotExistError(`postgresql-serverless adapter for database "${databaseName}" already dropped`);
    }

    return null;
  });
  log.debug(`finished dropping events tables`);
  return errors;
};

export default dropEvents;
//# sourceMappingURL=drop-events.js.map