import { EventstoreResourceNotExistError } from 'resolve-eventstore-base';
import getLog from './get-log';
import { isNotExistError } from './resource-errors';
import executeSequence from './execute-sequence';

const dropSecrets = async ({
  databaseName,
  executeStatement,
  escapeId,
  secretsTableName
}) => {
  const log = getLog('dropSecrets');
  log.debug(`dropping secrets`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  log.verbose(`databaseName: ${databaseName}`);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const globalIndexName = escapeId(`${secretsTableName}-global`);
  const databaseNameAsId = escapeId(databaseName);
  const statements = [`DROP TABLE ${databaseNameAsId}.${secretsTableNameAsId}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${globalIndexName}`];
  const errors = await executeSequence(executeStatement, statements, log, error => {
    if (isNotExistError(error.message)) {
      return new EventstoreResourceNotExistError(`postgresql-serverless adapter for database "${databaseName}" already dropped`);
    }

    return null;
  });
  log.debug(`finished dropping secrets`);
  return errors;
};

export default dropSecrets;
//# sourceMappingURL=drop-secrets.js.map