import { EventstoreResourceAlreadyExistError } from 'resolve-eventstore-base';
import getLog from './get-log';
import { AGGREGATE_ID_SQL_TYPE } from './constants';
import { isAlreadyExistsError } from './resource-errors';
import executeSequence from './execute-sequence';

const initSecrets = async ({
  databaseName,
  secretsTableName,
  executeStatement,
  escapeId
}) => {
  const log = getLog('initSecrets');
  log.debug(`initializing secrets table`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  log.verbose(`databaseName: ${databaseName}`);
  const databaseNameAsId = escapeId(databaseName);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const globalIndexName = escapeId(`${secretsTableName}-global`);
  const statements = [`CREATE TABLE IF NOT EXISTS ${databaseNameAsId}.${secretsTableNameAsId} (
      "idx" BIGSERIAL,
      "id" ${AGGREGATE_ID_SQL_TYPE} NOT NULL PRIMARY KEY,
      "secret" text COLLATE pg_catalog."default"
    )`, `CREATE UNIQUE INDEX IF NOT EXISTS ${globalIndexName}
    ON ${databaseNameAsId}.${secretsTableNameAsId}
    ("idx")`];
  const errors = await executeSequence(executeStatement, statements, log, error => {
    if (isAlreadyExistsError(error.message)) {
      return new EventstoreResourceAlreadyExistError(`duplicate initialization of the postgresql-serverless event store on database "${databaseName}" and table "${secretsTableName}" is not allowed`);
    }

    return null;
  });
  log.debug('finished initializing secrets table');
  return errors;
};

export default initSecrets;
//# sourceMappingURL=init-secrets.js.map