"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("./get-log"));

var _beginTransaction = _interopRequireDefault(require("./begin-transaction"));

var _commitTransaction = _interopRequireDefault(require("./commit-transaction"));

var _rollbackTransaction = _interopRequireDefault(require("./rollback-transaction"));

var _isTimeoutError = _interopRequireDefault(require("./is-timeout-error"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const connect = async (pool, {
  RDSDataService,
  escapeId,
  escape,
  fullJitter,
  executeStatement,
  coercer
}, config) => {
  var _eventsTableName, _snapshotsTableName, _secretsTableName;

  const log = (0, _getLog.default)('connect');
  log.debug('configuring RDS data service client');
  let {
    databaseName,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    // eslint-disable-next-line prefer-const
    ...connectionOptions
  } = config;
  eventsTableName = (_eventsTableName = eventsTableName) !== null && _eventsTableName !== void 0 ? _eventsTableName : 'events';
  snapshotsTableName = (_snapshotsTableName = snapshotsTableName) !== null && _snapshotsTableName !== void 0 ? _snapshotsTableName : 'snapshots';
  secretsTableName = (_secretsTableName = secretsTableName) !== null && _secretsTableName !== void 0 ? _secretsTableName : 'secrets';
  const {
    dbClusterOrInstanceArn,
    awsSecretStoreArn,
    ...rdsConfig
  } = connectionOptions;

  if (dbClusterOrInstanceArn == null || awsSecretStoreArn == null) {
    throw new Error(`Options "dbClusterOrInstanceArn" and "awsSecretStoreArn" are mandatory`);
  }

  const rdsDataService = new RDSDataService(rdsConfig);
  Object.assign(pool, {
    rdsDataService,
    dbClusterOrInstanceArn,
    awsSecretStoreArn,
    databaseName,
    eventsTableName,
    secretsTableName,
    snapshotsTableName,
    fullJitter,
    coercer,
    executeStatement: executeStatement.bind(null, pool),
    beginTransaction: _beginTransaction.default,
    commitTransaction: _commitTransaction.default,
    rollbackTransaction: _rollbackTransaction.default,
    escapeId,
    escape,
    isTimeoutError: _isTimeoutError.default
  });
  log.debug('RDS data service client configured');
};

var _default = connect;
exports.default = _default;
//# sourceMappingURL=connect.js.map