"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _resolveEventstoreBase = require("resolve-eventstore-base");

var _getLog = _interopRequireDefault(require("./get-log"));

var _resourceErrors = require("./resource-errors");

var _executeSequence = _interopRequireDefault(require("./execute-sequence"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const dropSecrets = async ({
  databaseName,
  executeStatement,
  escapeId,
  secretsTableName
}) => {
  const log = (0, _getLog.default)('dropSecrets');
  log.debug(`dropping secrets`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  log.verbose(`databaseName: ${databaseName}`);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const globalIndexName = escapeId(`${secretsTableName}-global`);
  const databaseNameAsId = escapeId(databaseName);
  const statements = [`DROP TABLE ${databaseNameAsId}.${secretsTableNameAsId}`, `DROP INDEX IF EXISTS ${databaseNameAsId}.${globalIndexName}`];
  const errors = await (0, _executeSequence.default)(executeStatement, statements, log, error => {
    if ((0, _resourceErrors.isNotExistError)(error.message)) {
      return new _resolveEventstoreBase.EventstoreResourceNotExistError(`postgresql-serverless adapter for database "${databaseName}" already dropped`);
    }

    return null;
  });
  log.debug(`finished dropping secrets`);
  return errors;
};

var _default = dropSecrets;
exports.default = _default;
//# sourceMappingURL=drop-secrets.js.map