"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.destroy = exports.dispose = exports.create = exports.default = void 0;

var _rdsdataservice = _interopRequireDefault(require("aws-sdk/clients/rdsdataservice"));

var _resolveEventstoreBase = _interopRequireDefault(require("resolve-eventstore-base"));

var _loadEventsByCursor = _interopRequireDefault(require("./load-events-by-cursor"));

var _loadEventsByTimestamp = _interopRequireDefault(require("./load-events-by-timestamp"));

var _freeze = _interopRequireDefault(require("./freeze"));

var _unfreeze = _interopRequireDefault(require("./unfreeze"));

var _getLatestEvent = _interopRequireDefault(require("./get-latest-event"));

var _saveEvent = _interopRequireDefault(require("./save-event"));

var _fullJitter = _interopRequireDefault(require("./full-jitter"));

var _executeStatement = _interopRequireDefault(require("./execute-statement"));

var _injectEvent = _interopRequireDefault(require("./inject-event"));

var _coercer = _interopRequireDefault(require("./coercer"));

var _escapeId = _interopRequireDefault(require("./escape-id"));

var _escape = _interopRequireDefault(require("./escape"));

var _shapeEvent = _interopRequireDefault(require("./shape-event"));

var _loadSnapshot = _interopRequireDefault(require("./load-snapshot"));

var _saveSnapshot = _interopRequireDefault(require("./save-snapshot"));

var _dropSnapshot = _interopRequireDefault(require("./drop-snapshot"));

var _beginIncrementalImport = _interopRequireDefault(require("./begin-incremental-import"));

var _commitIncrementalImport = _interopRequireDefault(require("./commit-incremental-import"));

var _rollbackIncrementalImport = _interopRequireDefault(require("./rollback-incremental-import"));

var _pushIncrementalImport = _interopRequireDefault(require("./push-incremental-import"));

var _connect = _interopRequireDefault(require("./connect"));

var _initEvents = _interopRequireDefault(require("./init-events"));

var _initSecrets = _interopRequireDefault(require("./init-secrets"));

var _initFinal = _interopRequireDefault(require("./init-final"));

var _dropEvents = _interopRequireDefault(require("./drop-events"));

var _dropSecrets = _interopRequireDefault(require("./drop-secrets"));

var _dropFinal = _interopRequireDefault(require("./drop-final"));

var _dispose = _interopRequireDefault(require("./dispose"));

var _deleteSecret = _interopRequireDefault(require("./delete-secret"));

var _setSecret = _interopRequireDefault(require("./set-secret"));

var _getSecret = _interopRequireDefault(require("./get-secret"));

var _injectSecret = _interopRequireDefault(require("./inject-secret"));

var _loadSecrets = _interopRequireDefault(require("./load-secrets"));

var _create = _interopRequireDefault(require("./resource/create"));

var _dispose2 = _interopRequireDefault(require("./resource/dispose"));

var _destroy = _interopRequireDefault(require("./resource/destroy"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// eslint-disable-next-line import/no-extraneous-dependencies
const createPostgresqlServerlessAdapter = options => {
  return (0, _resolveEventstoreBase.default)({
    connect: _connect.default,
    loadEventsByCursor: _loadEventsByCursor.default,
    loadEventsByTimestamp: _loadEventsByTimestamp.default,
    getLatestEvent: _getLatestEvent.default,
    saveEvent: _saveEvent.default,
    initEvents: _initEvents.default,
    initSecrets: _initSecrets.default,
    initFinal: _initFinal.default,
    dropEvents: _dropEvents.default,
    dropSecrets: _dropSecrets.default,
    dropFinal: _dropFinal.default,
    dispose: _dispose.default,
    freeze: _freeze.default,
    unfreeze: _unfreeze.default,
    shapeEvent: _shapeEvent.default,
    deleteSecret: _deleteSecret.default,
    getSecret: _getSecret.default,
    setSecret: _setSecret.default,
    loadSnapshot: _loadSnapshot.default,
    saveSnapshot: _saveSnapshot.default,
    dropSnapshot: _dropSnapshot.default,
    beginIncrementalImport: _beginIncrementalImport.default,
    commitIncrementalImport: _commitIncrementalImport.default,
    rollbackIncrementalImport: _rollbackIncrementalImport.default,
    pushIncrementalImport: _pushIncrementalImport.default,
    injectEvent: _injectEvent.default,
    injectSecret: _injectSecret.default,
    loadSecrets: _loadSecrets.default
  }, {
    RDSDataService: _rdsdataservice.default,
    escapeId: _escapeId.default,
    escape: _escape.default,
    fullJitter: _fullJitter.default,
    executeStatement: _executeStatement.default,
    coercer: _coercer.default
  }, options);
};

var _default = createPostgresqlServerlessAdapter;
exports.default = _default;
const cloudPool = {
  executeStatement: _executeStatement.default,
  connect: _connect.default,
  RDSDataService: _rdsdataservice.default,
  escapeId: _escapeId.default,
  escape: _escape.default,
  fullJitter: _fullJitter.default,
  coercer: _coercer.default,
  dispose: _dispose.default,
  shapeEvent: _shapeEvent.default
};

const createResource = _create.default.bind(null, cloudPool);

exports.create = createResource;

const disposeResource = _dispose2.default.bind(null, cloudPool);

exports.dispose = disposeResource;

const destroyResource = _destroy.default.bind(null, cloudPool);

exports.destroy = destroyResource;
Object.assign(cloudPool, {
  createResource,
  disposeResource,
  destroyResource
});
//# sourceMappingURL=index.js.map