"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _resolveEventstoreBase = require("resolve-eventstore-base");

var _getLog = _interopRequireDefault(require("./get-log"));

var _constants = require("./constants");

var _resourceErrors = require("./resource-errors");

var _executeSequence = _interopRequireDefault(require("./execute-sequence"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const initSecrets = async ({
  databaseName,
  secretsTableName,
  executeStatement,
  escapeId
}) => {
  const log = (0, _getLog.default)('initSecrets');
  log.debug(`initializing secrets table`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  log.verbose(`databaseName: ${databaseName}`);
  const databaseNameAsId = escapeId(databaseName);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const globalIndexName = escapeId(`${secretsTableName}-global`);
  const statements = [`CREATE TABLE IF NOT EXISTS ${databaseNameAsId}.${secretsTableNameAsId} (
      "idx" BIGSERIAL,
      "id" ${_constants.AGGREGATE_ID_SQL_TYPE} NOT NULL PRIMARY KEY,
      "secret" text COLLATE pg_catalog."default"
    )`, `CREATE UNIQUE INDEX IF NOT EXISTS ${globalIndexName}
    ON ${databaseNameAsId}.${secretsTableNameAsId}
    ("idx")`];
  const errors = await (0, _executeSequence.default)(executeStatement, statements, log, error => {
    if ((0, _resourceErrors.isAlreadyExistsError)(error.message)) {
      return new _resolveEventstoreBase.EventstoreResourceAlreadyExistError(`duplicate initialization of the postgresql-serverless event store on database "${databaseName}" and table "${secretsTableName}" is not allowed`);
    }

    return null;
  });
  log.debug('finished initializing secrets table');
  return errors;
};

var _default = initSecrets;
exports.default = _default;
//# sourceMappingURL=init-secrets.js.map