"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("../get-log"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const create = async (pool, options) => {
  const log = (0, _getLog.default)('resource:create');
  const {
    executeStatement: _executeStatement,
    connect: _connect,
    RDSDataService,
    escapeId,
    escape,
    fullJitter,
    coercer,
    dispose: _dispose
  } = pool;
  const connect = _connect;
  const executeStatement = _executeStatement;
  const dispose = _dispose;
  log.debug(`configuring adapter with environment privileges`);
  const adminPool = {};
  log.debug(`connecting the adapter`);
  await connect(adminPool, {
    RDSDataService,
    escapeId,
    escape,
    fullJitter,
    executeStatement,
    coercer
  }, {
    region: options.region,
    awsSecretStoreArn: options.awsSecretStoreAdminArn,
    dbClusterOrInstanceArn: options.dbClusterOrInstanceArn,
    databaseName: options.databaseName,
    eventsTableName: options.eventsTableName,
    secretsTableName: options.secretsTableName,
    snapshotsTableName: options.snapshotsTableName
  });
  log.debug(`building schema and granting privileges to user`);
  await executeStatement(adminPool, [`CREATE SCHEMA ${escapeId(options.databaseName)}`, `GRANT USAGE ON SCHEMA ${escapeId(options.databaseName)} TO ${escapeId(options.userLogin)}`, `GRANT ALL ON SCHEMA ${escapeId(options.databaseName)} TO ${escapeId(options.userLogin)}`, `GRANT ALL ON ALL TABLES IN SCHEMA ${escapeId(options.databaseName)} TO ${escapeId(options.userLogin)}`, `GRANT ALL ON ALL SEQUENCES IN SCHEMA ${escapeId(options.databaseName)} TO ${escapeId(options.userLogin)}`, `GRANT ALL ON ALL FUNCTIONS IN SCHEMA ${escapeId(options.databaseName)} TO ${escapeId(options.userLogin)}`, `ALTER SCHEMA ${escapeId(options.databaseName)} OWNER TO ${escapeId(options.userLogin)}`].join('; '));
  log.debug(`disposing the adapter`);
  await dispose(adminPool);
  log.debug(`resource created successfully`);
};

var _default = create;
exports.default = _default;
//# sourceMappingURL=create.js.map