"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("./get-log"));

var _resolveEventstoreBase = require("resolve-eventstore-base");

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const saveSnapshot = async (pool, snapshotKey, content) => (0, _resolveEventstoreBase.snapshotTrigger)(pool, snapshotKey, content, async () => {
  const log = (0, _getLog.default)(`saveSnapshot:${snapshotKey}`);
  const {
    databaseName,
    snapshotsTableName,
    executeStatement,
    escapeId,
    escape,
    beginTransaction,
    commitTransaction,
    rollbackTransaction
  } = pool;
  const databaseNameAsId = escapeId(databaseName);
  const snapshotsTableNameAsId = escapeId(snapshotsTableName);
  const chunksCount = Math.ceil(content.length / _constants.SAVE_CHUNK_SIZE);

  if (chunksCount > 1) {
    log.debug(`writing the snapshot to database (chunked)`);
    let transactionId = null;

    try {
      transactionId = await beginTransaction(pool);

      for (let index = 0; index < chunksCount; index++) {
        const chunk = content.substring(index * _constants.SAVE_CHUNK_SIZE, (index + 1) * _constants.SAVE_CHUNK_SIZE);

        if (index > 0) {
          await executeStatement(`UPDATE ${databaseNameAsId}.${snapshotsTableNameAsId}
            SET "snapshotContent" = "snapshotContent" || ${escape(chunk)}
            WHERE "snapshotKey" = ${escape(snapshotKey)}`, transactionId);
        } else {
          await executeStatement(`INSERT INTO ${databaseNameAsId}.${snapshotsTableNameAsId}(
              "snapshotKey", 
              "snapshotContent"
            )
            VALUES(${escape(snapshotKey)}, ${escape(chunk)})
            ON CONFLICT ("snapshotKey") DO UPDATE
            SET "snapshotContent" = ${escape(chunk)}`, transactionId);
        }
      }

      await commitTransaction(pool, transactionId);
    } catch (error) {
      await rollbackTransaction(pool, transactionId);
      throw error;
    }
  } else {
    log.debug(`writing the snapshot to database (whole)`);
    await executeStatement(`INSERT INTO ${databaseNameAsId}.${snapshotsTableNameAsId}(
        "snapshotKey", 
        "snapshotContent"
      )
      VALUES(${escape(snapshotKey)}, ${escape(content)})
      ON CONFLICT ("snapshotKey") DO UPDATE
      SET "snapshotContent" = ${escape(content)}`);
  }

  log.debug(`the snapshot saved successfully`);
});

var _default = saveSnapshot;
exports.default = _default;
//# sourceMappingURL=save-snapshot.js.map